summaryrefslogtreecommitdiffstats
path: root/ext/dv
diff options
context:
space:
mode:
authorTim-Philipp Müller <tim@centricular.net>2007-06-08 10:43:26 +0000
committerTim-Philipp Müller <tim@centricular.net>2007-06-08 10:43:26 +0000
commit08d5dedbaa5344e22174d53edbd8258b9434b4c4 (patch)
tree655c7561bc1d46a165bfa9fbd67ba1fc96c50c72 /ext/dv
parent51e52ed2cfbddb0f382d48a6cb962b6697b2cc91 (diff)
ext/: When operating in pull mode, error out correct on not-linked.
Original commit message from CVS: * ext/dv/gstdvdemux.c: (gst_dvdemux_loop): * ext/libpng/gstpngdec.c: (user_read_data), (gst_pngdec_task): When operating in pull mode, error out correct on not-linked.
Diffstat (limited to 'ext/dv')
-rw-r--r--ext/dv/gstdvdemux.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/ext/dv/gstdvdemux.c b/ext/dv/gstdvdemux.c
index fb47bb31..749b755b 100644
--- a/ext/dv/gstdvdemux.c
+++ b/ext/dv/gstdvdemux.c
@@ -1681,10 +1681,10 @@ small_buffer:
}
pause:
{
- GST_LOG_OBJECT (dvdemux, "pausing task %d", ret);
+ GST_INFO_OBJECT (dvdemux, "pausing task, %s", gst_flow_get_name (ret));
dvdemux->running = FALSE;
gst_pad_pause_task (dvdemux->sinkpad);
- if (GST_FLOW_IS_FATAL (ret)) {
+ if (GST_FLOW_IS_FATAL (ret) || ret == GST_FLOW_NOT_LINKED) {
if (ret == GST_FLOW_UNEXPECTED) {
GST_LOG_OBJECT (dvdemux, "got eos");
/* perform EOS logic */
@@ -1697,7 +1697,7 @@ pause:
gst_dvdemux_push_event (dvdemux, gst_event_new_eos ());
}
} else {
/* for fatal errors we post an error message */
GST_ELEMENT_ERROR (dvdemux, STREAM, FAILED,
(NULL), ("streaming stopped, reason %s", gst_flow_get_name (ret)));
gst_dvdemux_push_event (dvdemux, gst_event_new_eos ());
@@ -1697,7 +1697,7 @@ pause:
}
} else {
- /* for fatal errors we post an error message */
+ /* for fatal errors or not-linked we post an error message */
GST_ELEMENT_ERROR (dvdemux, STREAM, FAILED,
(NULL), ("streaming stopped, reason %s", gst_flow_get_name (ret)));